/* Automatically generated file.  Do not edit */
#define OP_Goto                          1
#define OP_Gosub                         2
#define OP_Return                        3
#define OP_Halt                          4
#define OP_Integer                       5
#define OP_String                        6
#define OP_Pop                           7
#define OP_Dup                           8
#define OP_Pull                          9
#define OP_Push                         10
#define OP_ColumnCount                  11
#define OP_ColumnName                   12
#define OP_Callback                     13
#define OP_NullCallback                 14
#define OP_Concat                       15
#define OP_Add                          16
#define OP_Subtract                     17
#define OP_Multiply                     18
#define OP_Divide                       19
#define OP_Remainder                    20
#define OP_Function                     21
#define OP_BitAnd                       22
#define OP_BitOr                        23
#define OP_ShiftLeft                    24
#define OP_ShiftRight                   25
#define OP_AddImm                       26
#define OP_MustBeInt                    27
#define OP_Eq                           28
#define OP_Ne                           29
#define OP_Lt                           30
#define OP_Le                           31
#define OP_Gt                           32
#define OP_Ge                           33
#define OP_StrEq                        34
#define OP_StrNe                        35
#define OP_StrLt                        36
#define OP_StrLe                        37
#define OP_StrGt                        38
#define OP_StrGe                        39
#define OP_And                          40
#define OP_Or                           41
#define OP_Negative                     42
#define OP_AbsValue                     43
#define OP_Not                          44
#define OP_BitNot                       45
#define OP_Noop                         46
#define OP_If                           47
#define OP_IfNot                        48
#define OP_IsNull                       49
#define OP_NotNull                      50
#define OP_MakeRecord                   51
#define OP_MakeIdxKey                   52
#define OP_MakeKey                      53
#define OP_IncrKey                      54
#define OP_Checkpoint                   55
#define OP_Transaction                  56
#define OP_Commit                       57
#define OP_Rollback                     58
#define OP_ReadCookie                   59
#define OP_SetCookie                    60
#define OP_VerifyCookie                 61
#define OP_OpenAux                      62
#define OP_OpenWrAux                    63
#define OP_OpenWrite                    64
#define OP_Open                         65
#define OP_OpenTemp                     66
#define OP_RenameCursor                 67
#define OP_Close                        68
#define OP_MoveLt                       69
#define OP_MoveTo                       70
#define OP_Distinct                     71
#define OP_NotFound                     72
#define OP_Found                        73
#define OP_IsUnique                     74
#define OP_NotExists                    75
#define OP_NewRecno                     76
#define OP_PutIntKey                    77
#define OP_PutStrKey                    78
#define OP_Delete                       79
#define OP_KeyAsData                    80
#define OP_Column                       81
#define OP_Recno                        82
#define OP_FullKey                      83
#define OP_NullRow                      84
#define OP_Last                         85
#define OP_Rewind                       86
#define OP_Prev                         87
#define OP_Next                         88
#define OP_IdxPut                       89
#define OP_IdxDelete                    90
#define OP_IdxRecno                     91
#define OP_IdxLT                        92
#define OP_IdxGT                        93
#define OP_IdxGE                        94
#define OP_Destroy                      95
#define OP_Clear                        96
#define OP_CreateIndex                  97
#define OP_CreateTable                  98
#define OP_IntegrityCk                  99
#define OP_ListWrite                   100
#define OP_ListRewind                  101
#define OP_ListRead                    102
#define OP_ListReset                   103
#define OP_ListPush                    104
#define OP_ListPop                     105
#define OP_SortPut                     106
#define OP_SortMakeRec                 107
#define OP_SortMakeKey                 108
#define OP_Sort                        109
#define OP_SortNext                    110
#define OP_SortCallback                111
#define OP_SortReset                   112
#define OP_FileOpen                    113
#define OP_FileRead                    114
#define OP_FileColumn                  115
#define OP_MemStore                    116
#define OP_MemLoad                     117
#define OP_MemIncr                     118
#define OP_AggReset                    119
#define OP_AggInit                     120
#define OP_AggFunc                     121
#define OP_AggFocus                    122
#define OP_AggSet                      123
#define OP_AggGet                      124
#define OP_AggNext                     125
#define OP_SetInsert                   126
#define OP_SetFound                    127
#define OP_SetNotFound                 128
#define OP_SetFirst                    129
#define OP_SetNext                     130
